app

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AdapterModule

func AdapterModule() (fx.Option, error)

AdapterModule creates an Fx module that provides the K8S adapter and Decision Maker client

func ConfigModule

func ConfigModule(cfg config.ManageConfig) (fx.Option, error)

ConfigModule creates an Fx module that provides configuration structs

func HandlerModule

func HandlerModule(serviceModule fx.Option) (fx.Option, error)

HandlerModule creates an Fx module that provides the REST handler, return *rest.Handler

func NewRestApp

func NewRestApp(configName string, configDirPath string) (*fx.App, error)

func RepoModule

func RepoModule(cfg config.ManageConfig) (fx.Option, error)

RepoModule creates an Fx module that provides the repository layer, return repository.Repository

func ServiceModule

func ServiceModule(adapterModule, repoModule fx.Option) (fx.Option, error)

ServiceModule creates an Fx module that provides the service layer, return domain.Service

func StartIntentReconciler added in v1.2.1

func StartIntentReconciler(lc fx.Lifecycle, svc domain.Service) error

StartIntentReconciler starts a background goroutine that periodically reconciles scheduling intents. This handles: - Manager restart: re-sends all intents from DB to DM pods - Decision Maker restart: detects Merkle root mismatch and re-sends intents - Pod restart: detects stale intents and creates new ones for replacement pods

func StartRestApp

func StartRestApp(lc fx.Lifecycle, cfg config.ServerConfig, handler *rest.Handler) error

func TestRepoModule

func TestRepoModule(cfg config.ManageConfig, containerBuilder *container.ContainerBuilder) (fx.Option, error)

TestRepoModule creates an Fx module that provides the repository layer for testing, return repository.Repository

Types

This section is empty.

Jump to