Documentation
¶
Index ¶
- func AdapterModule() (fx.Option, error)
- func ConfigModule(cfg config.ManageConfig) (fx.Option, error)
- func HandlerModule(serviceModule fx.Option) (fx.Option, error)
- func NewRestApp(configName string, configDirPath string) (*fx.App, error)
- func RepoModule(cfg config.ManageConfig) (fx.Option, error)
- func ServiceModule(adapterModule, repoModule fx.Option) (fx.Option, error)
- func StartIntentReconciler(lc fx.Lifecycle, svc domain.Service) error
- func StartRestApp(lc fx.Lifecycle, cfg config.ServerConfig, handler *rest.Handler) error
- func TestRepoModule(cfg config.ManageConfig, containerBuilder *container.ContainerBuilder) (fx.Option, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AdapterModule ¶
AdapterModule creates an Fx module that provides the K8S adapter and Decision Maker client
func ConfigModule ¶
func ConfigModule(cfg config.ManageConfig) (fx.Option, error)
ConfigModule creates an Fx module that provides configuration structs
func HandlerModule ¶
HandlerModule creates an Fx module that provides the REST handler, return *rest.Handler
func RepoModule ¶
func RepoModule(cfg config.ManageConfig) (fx.Option, error)
RepoModule creates an Fx module that provides the repository layer, return repository.Repository
func ServiceModule ¶
ServiceModule creates an Fx module that provides the service layer, return domain.Service
func StartIntentReconciler ¶ added in v1.2.1
StartIntentReconciler starts a background goroutine that periodically reconciles scheduling intents. This handles: - Manager restart: re-sends all intents from DB to DM pods - Decision Maker restart: detects Merkle root mismatch and re-sends intents - Pod restart: detects stale intents and creates new ones for replacement pods
func StartRestApp ¶
func TestRepoModule ¶
func TestRepoModule(cfg config.ManageConfig, containerBuilder *container.ContainerBuilder) (fx.Option, error)
TestRepoModule creates an Fx module that provides the repository layer for testing, return repository.Repository
Types ¶
This section is empty.